.. parasweep documentation master file, created by
   sphinx-quickstart on Wed Jan 16 03:08:19 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to parasweep's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   contributing
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
